Shared Normative Type (NT) data model types.
These types represent the PVAccess Normative Types used across the codec, client tools, server, and packet capture subsystems.
Structs
- NdCodec
- NdDimension
- NtAlarm
- NtAttribute
- NtControl
- NtDisplay
- NtEnum
- NTEnum normative type — represents an enumerated PV value.
- NtNd
Array - NtScalar
- NtScalar
Array - NtTable
- NtTable
Column - NtTime
Stamp
Enums
- NtPayload
- PvValue
- A recursive value type that can represent any PVA structure without
depending on the codec crate. Used by
NtPayload::Genericto carry group-PV composite values and other non-normative structures. - Scalar
Array Value - Scalar
Value