Crate spvirit_types

Crate spvirit_types 

Shared Normative Type (NT) data model types.

These types represent the PVAccess Normative Types used across the codec, client tools, server, and packet capture subsystems.

Structs

NdCodec
NdDimension
NtAlarm
NtAttribute
NtControl
NtDisplay
NtEnum
NTEnum normative type — represents an enumerated PV value.
NtNdArray
NtScalar
NtScalarArray
NtTable
NtTableColumn
NtTimeStamp

Enums

NtPayload
PvValue
A recursive value type that can represent any PVA structure without depending on the codec crate. Used by NtPayload::Generic to carry group-PV composite values and other non-normative structures.
ScalarArrayValue
ScalarValue